// **************************************************************************************
// el Comandante                                                    guerilla.bplaced.net
// --------------------------------------------------------------------------------------
// Information:
// Dual LED Bargraph Breakout Board, I2C Interface, I/O Expander MCP23017, 2/3/4/5-Wire (SDA, SCL, !RES, INTA, INTB)
// --------------------------------------------------------------------------------------
// Libraries:
// MCP23017   --> https://github.com/wollewald/MCP23017_WE
// --------------------------------------------------------------------------------------
// Documentations:
// Overview ESP32 mcu's   - https://socialcompare.com/en/comparison/esp8266-vs-esp32-vs-esp32-s2
// Espressif ESP32 docu's - https://www.espressif.com/en/support/documents/technical-documents
// --------------------------------------------------------------------------------------
// Device WT32-SC01       - http://myosuploads3.banggood.com/products/20220111/20220111020446WT32-SC01DataSheetV3.3.pdf
// TFT Device ST7796      - https://cdn.hackaday.io/files/1625926956336128/ST7796S.pdf
// Touch Device FT6336U   - https://focuslcds.com/content/FT6236.pdf
// --------------------------------------------------------------------------------------
// Device TTGO-T-Display  - https://github.com/Xinyuan-LilyGO/TTGO-T-Display
// TFT Device ST7789V     - https://newhavendisplay.com/content/datasheets/ST7789V.pdf
// **************************************************************************************
#include <Wire.h>                                         // Arduino Wire library
#include <MCP23017.h>                                     // MCP23017 library

// ######################################################################################
// Change values in this area to match your envoirement and desires
// --------------------------------------------------------------------------------------
// I2C pins, i.e. WT32-SC01 (SDA 18,SCL 19,!RES 25), TTGO T Display (SDA 21,SCL 22,!RES 25)
#define         SDA 18                                    // I2C interface
#define         SCL 19                                    // I2C interface
#define         RES 25                                    // !Reset signal
#define         I2CMCP_ADR 0x20                           // I2C address (A0,A1,A2 = LOW)
#define         Speed 500                                 // Speed next LED on
// ######################################################################################

// Vars
uint8_t         i;                                        // index var

// Object(s)
MCP23017        I2CMCP = MCP23017(I2CMCP_ADR, RES);       // MCP23017

// **************************************************************************************
// Setup
// **************************************************************************************
void setup()
{
  Serial.begin(115200);
  delay (1000);

  Wire.begin(SDA, SCL);                                   // i2c - init
  delay (1000);

  if(!I2CMCP.Init())
  {
    Serial.println("Not connected!");
    while(1)
    {
    } 
  }

  I2CMCP.setPortMode(0b11111111, A);                      // Port A, all pins are OUTPUT
  I2CMCP.setPortMode(0b11111111, B);                      // Port B, all pins are OUTPUT
  delay(1000);
  I2CMCP.setAllPins(A, ON);                               // all LEDs Port A, switched on
  I2CMCP.setAllPins(B, ON);                               // all LEDs Port B, switched on
  delay(2000);
}

// **************************************************************************************
// Main Loop
// **************************************************************************************
void loop()
{
  I2CMCP.setAllPins(A, OFF);                              // all LEDs Port A, switched off
  I2CMCP.setAllPins(B, OFF);                              // all LEDs Port B, switched off
  delay(2000);
  
  for(i = 0; i < 8; i++)                                  // LEDs 1-8 Port A, switched on
  {
    I2CMCP.setPinX(i, A, OUTPUT, HIGH);
    delay(Speed);
  }

  for(i = 0; i < 8; i++)                                  // LEDs 1-8 Port B, switched on
  {
    I2CMCP.setPinX(i, B, OUTPUT, HIGH);
    delay(Speed);
  }

  I2CMCP.setAllPins(A, OFF);                              // all LEDs Port A, switched off
  I2CMCP.setAllPins(B, OFF);                              // all LEDs Port B, switched off
  delay(2000);

  for(i = 0; i < 8; i++)                                  // LEDs 1-8 Port A and Port B, switched on
  {
    I2CMCP.setPinX(i, A, OUTPUT, HIGH);
    I2CMCP.setPinX(i, B, OUTPUT, HIGH);
    delay(Speed);
  }
}
